@@ -116,15 +116,22 @@ bayesDensity <- function(dir = getwd(),
   if (!standard) nstgrid <- 0
   if (!center) ncentgrid <- 0
 
-  mcmc <- .C("bayesDensity", aver = double(ngrid * (1 + k.max)),           staver = double(nstgrid * (1 + k.max)),
+  mcmc <- .C(C_bayesDensity, aver = double(ngrid * (1 + k.max)),
+                             staver = double(nstgrid * (1 + k.max)),
                              centaver = double(ncentgrid * (1 + k.max)),
-                             intercept = double(lvalue),                   scale = double(lvalue),
-                             M.k = integer(1 + k.max),                     as.character(dir),
-                             as.double(grid),                              as.double(stgrid),
+                             intercept = double(lvalue),
+                             scale = double(lvalue),
+                             M.k = integer(1 + k.max),
+                             as.character(dir),
+                             as.double(grid),
+                             as.double(stgrid),
                              as.double(centgrid),
-                             as.integer(k.max),                            as.integer(M),
-                             as.integer(skip),                             as.integer(by),
-                             as.integer(ngrid),                            as.integer(nstgrid),
+                             as.integer(k.max),
+                             as.integer(M),
+                             as.integer(skip),
+                             as.integer(by),
+                             as.integer(ngrid),
+                             as.integer(nstgrid),
                              as.integer(ncentgrid),
                              err = integer(1),
              PACKAGE = thispackage)
